@@ -1,6 +1,6 @@
 /**************************************************************************
-**  settingshandler.h (of Suova)
-**  Copyright (c) 2012 Heli Hyvättinen
+**  settingshandler.h (of CountYourScores)
+**  Copyright (c) 2012–2013 Heli Hyvättinen
 **
 **  This program is free software: you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
 **
 **  See <http://www.gnu.org/licenses/>
 **
-**  SettingsHandler 21.8.2012
+**  SettingsHandler 18.3.2013
 **************************************************************************/
 
 #ifndef SETTINGSHANDLER_H
@@ -32,6 +32,13 @@ public:
 //        Q_INVOKABLE QStringList getSetNames();
     
     Q_INVOKABLE bool setNameExists(QString name);
+
+    Q_INVOKABLE bool isBlackThemeOn();
+
+    Q_INVOKABLE QString currentSet();
+
+    Q_INVOKABLE QStringList setNames(bool includeDefault);
+
 signals:
     
 public slots:
@@ -44,6 +51,12 @@ public slots:
 
         void finishSet(QString name);
 
+        void setBlackTheme(bool on);
+
+        void saveCurrentSet(QString setName);
+
+        void removeSet(QString name);
+
 private:
 
     QList<int> numberSet_;
